# -*- coding: utf-8 -*-

from qt4w.webcontrols import *

'''
Ke WebPage类
'''


class OEDWebPage(WebPage):
    def __init__(self, webview_or_webpage):
        super(OEDWebPage, self).__init__(webview_or_webpage)
